@@ -1,4 +1,9 @@
 /*
+ * $Source: /cvsroot/cgoban1/cgoban1/src/cgbuts.c,v $
+ * $Revision: 1.2 $
+ * $Author: wmshub $
+ * $Date: 2002/05/31 23:40:54 $
+ *
  * src/cgbuts.c, part of Complete Goban (game program)
  * Copyright (C) 1995-1996 William Shubert.
  * See "configure.h.in" for more copyright information.
@@ -500,6 +505,15 @@ void  cgbuts_markPiece(Cgbuts *b, ButWin *win, GoStone piece,
     points[3] = points[0];
     XDrawLines(dpy, win->win, gc, points, 4, CoordModeOrigin);
     break;
+  case goMark_x:
+    off = (int)(w*0.14644661+lw*0.5+1.5);
+    XDrawLine(dpy, win->win, gc,
+	      x + off - win->xOff, y + off - win->yOff,
+	      x + w - off - win->xOff-(lw&1), y + w - off - win->yOff-(lw&1));
+    XDrawLine(dpy, win->win, gc,
+	      x + off - win->xOff,  y + w - off  - win->yOff-(lw&1),
+	      x + w - off - win->xOff-(lw&1), y + off - win->yOff);
+    break;
   case goMark_ko:
   case goMark_square:
     off = (int)(w*0.14644661+lw*0.5+0.5);
