@@ -1,4 +1,9 @@
 /*
+ * $Source: /cvsroot/cgoban1/cgoban1/src/cgbuts.h,v $
+ * $Revision: 1.2 $
+ * $Author: wmshub $
+ * $Date: 2002/05/31 23:40:54 $
+ *
  * src/cgbuts.h, part of Complete Goban (game program)
  * Copyright (C) 1995 William Shubert.
  * See "configure.h.in" for more copyright information.
@@ -75,7 +80,7 @@ typedef struct Cgbuts_struct  {
 
 typedef enum  {
   goMark_none,   goMark_lastMove, goMark_ko,
-  goMark_triangle, goMark_square, goMark_circle,
+  goMark_triangle, goMark_x, goMark_square, goMark_circle,
   goMark_letter, goMark_number, goMark_smWhite, goMark_smBlack
 } GoMarkType;
 #define  goMark_max  (goMark_ko + 1)
