@@ -1,7 +1,7 @@
 /*
- * $Source: /cvs/cgoban/src/cgoban.c,v $
- * $Revision: 1.2 $
- * $Date: 2002/02/28 03:34:35 $
+ * $Source: /cvsroot/cgoban1/cgoban1/src/cgoban.c,v $
+ * $Revision: 1.4 $
+ * $Date: 2002/12/17 22:46:56 $
  *
  * src/cgoban.c, part of Complete Goban (game program)
  * Copyright (C) 1995-1996 William Shubert
@@ -61,7 +61,7 @@ const ButKey  cg_help[] = {{XK_Help, 0, 0}, {0,0,0}};
 Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
   Cgoban  *cg;
   static const ClpSetup  commandLine[] = {
-    CLPSETUP_MSG("Complete Goban " VERSION " by William Shubert - " DATE),
+    CLPSETUP_MSG("Complete Goban " VERSION " by William Shubert, Kevin Sonney - " DATE),
     CLPSETUP_MSG(""),
     {"VersionNumber", VERSION, NULL, 0, NULL},
     {"version,-version", "f", "Print version information",
@@ -100,7 +100,7 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
     {"help.y", "", NULL, 0, NULL},
     {"help.w", "28.284271", NULL, 0, NULL},
     {"help.h", "40.0", NULL, 0, NULL},
-    {"game.rules", "0", NULL, 0, checkRules},
+    {"game.rules", "1", NULL, 0, checkRules},
     {"game.size", "19", NULL, 0, checkSize},
     {"game.komi", "5.5", NULL, 0, checkKomi},
     {"game.handicap", "0", NULL, 0, checkHandicap},
@@ -137,8 +137,8 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
     {"config.h", "0.70710678", NULL, 0, NULL},
     {"gmp.WOption", "0", NULL, 0, checkGmpOption},
     {"gmp.BOption", "0", NULL, 0, checkGmpOption},
-    {"gmp.WProgram", "./goDummy", NULL, 0, NULL},
-    {"gmp.BProgram", "./goDummy", NULL, 0, NULL},
+    {"gmp.WProgram", "/usr/bin/gnugo --mode gmp --quiet", NULL, 0, NULL},
+    {"gmp.BProgram", "/usr/bin/gnugo --mode gmp --quiet", NULL, 0, NULL},
     {"gmp.WDevice", "/dev/cua0", NULL, 0, NULL},
     {"gmp.BDevice", "/dev/cua1", NULL, 0, NULL},
     {"gmp.machine", "localhost", NULL, 0, NULL},
@@ -215,7 +215,7 @@ Cgoban  *cgoban_create(int argc, char *argv[], char *envp[])  {
   cg->clp = clp_create(commandLine);
   clp_rCmdline(cg->clp, argv);
   if (clp_getBool(cg->clp, "version"))  {
-    printf("cgoban version " VERSION " by William Shubert - " DATE "\n");
+    printf("cgoban version " VERSION " by William Shubert, Kevin Sonney - " DATE "\n");
     exit(0);
   }
   if (clp_getInt(cg->clp, "arena.games") > 0)  {
