@@ -240,7 +240,7 @@ void  cliGameList_gotMove(CliGameList *gl, const char *buf)  {
     g = &gl->games[gl->defaultGame];
     args = sscanf(buf, "%d(%c): %5s", &moveNum, &color, locStr);
     assert(args == 3);
-    if (!strcmp(locStr, "Handi"))  {
+    if (!strncmp(locStr, "Handi",5))  {
       sscanf(buf, "%*s %*s %d", &handicap);
       if (handicap != g->handicap)  {
 	g->handicap = handicap;
