@@ -634,6 +634,8 @@ static GobanOut  savePressed(void *packet)  {
 
 static void  saveFile(AbutFsel *fsel, void *packet, const char *fname)  {
   EditBoard  *e = packet;
+  int error;
+  Str str;
 
   assert(MAGIC(e));
   str_copy(&e->cg->lastDirAccessed, &fsel->pathVal);
@@ -644,7 +646,13 @@ static void  saveFile(AbutFsel *fsel, void *packet, const char *fname)  {
     e->tools.modified = FALSE;
     if (e->info)
       editInfo_updateSgf(e->info);
-    sgf_writeFile(e->sgf, fname, NULL);
+    if (!sgf_writeFile(e->sgf, fname, &error)) {
+      str_init(&str);
+      str_print(&str, "Error saving file \"%s\": %s",
+		fname, strerror(errno));
+      cgoban_createMsgWindow(e->cg, "Cgoban Error", str_chars(&str));
+      str_deinit(&str);
+    }
   }
   e->fsel = NULL;
 }
