@@ -1,7 +1,7 @@
 /*
- * $Source: /home/wms/cvs/cgoban/src/goGame.c,v $
- * $Revision: 1.2 $
- * $Date: 2000/02/26 23:03:46 $
+ * $Source: /cvsroot/cgoban1/cgoban1/src/goGame.c,v $
+ * $Revision: 1.3 $
+ * $Date: 2002/05/10 05:30:36 $
  *
  * src/gogame.c, part of Complete Goban (game program)
  * Copyright  1995-2000 William Shubert.
@@ -406,7 +406,7 @@ GoStone  goGame_whoseTurnOnMove(GoGame *game, int moveNum)  {
 
       
 static bool  goGame_forcedHandicapPlacement(GoGame *game)  {
-  return(!goRules_freeHandicaps[game->rules] &&
+  return(!goRules_freeHandicaps[game->rules] && !game->passive &&
 	 (game->size >= 9) && (game->size & 1) && (game->handicap <= 9));
 }
 
