@@ -1,4 +1,8 @@
 /*
+ * $Source: /cvsroot/cgoban1/cgoban1/src/goban.c,v $
+ * $Revision: 1.2 $
+ * $Date: 2002/02/28 03:34:35 $
+ *
  * src/goban.c, part of Complete Goban (game program)
  * Copyright (C) 1995-1997 William Shubert
  * See "configure.h.in" for more copyright information.
@@ -98,6 +102,8 @@ Goban  *goban_create(Cgoban *cg, const GobanActions *actions,void *packet,
   str_init(&clpStrs);
   str_print(&clpStrs, "%s.bProp", clpName);
   g->bProp = clp_lookup(cg->clp, str_chars(&clpStrs));
+  str_print(&clpStrs, "%s.bPropW", clpName);
+  g->bPropW = clp_lookup(cg->clp, str_chars(&clpStrs));
   str_print(&clpStrs, "%s.x", clpName);
   g->clpX = clp_lookup(cg->clp, str_chars(&clpStrs));
   str_print(&clpStrs, "%s.y", clpName);
@@ -105,7 +111,8 @@ Goban  *goban_create(Cgoban *cg, const GobanActions *actions,void *packet,
   str_deinit(&clpStrs);
   winSize = WIN_W(cg->fontH, butEnv_stdBw(cg->env));
   
-  g->win = butWin_iCreate(g, cg->env, title, winSize,
+  g->win = butWin_iCreate(g, cg->env, title,
+			  (int)(winSize * clpEntry_getDouble(g->bPropW) + 0.5),
 			  (int)(winSize * clpEntry_getDouble(g->bProp) + 0.5),
 			  &g->iWin, FALSE, 64,64, NULL, NULL, resize,
 			  iResize, destroy);
@@ -272,6 +279,7 @@ static ButOut  resize(ButWin *win)  {
   butW = fontH * 10 + bw*4;
   boardW = winW - butW - fontH*3 - bw*2;
   clpEntry_setDouble(g->bProp, (double)winH / (double)butWin_getMinH(win));
+  clpEntry_setDouble(g->bPropW, (double)winW / (double)butWin_getMinW(win)/2.0);
 
   butH = fontH * 2;
   butSpc = fontH * 2 + bw;
