@@ -1,4 +1,9 @@
 /*
+ * $Source: /cvsroot/cgoban1/cgoban1/src/sgfIn.c,v $
+ * $Revision: 1.3 $
+ * $Author: wmshub $
+ * $Date: 2002/05/31 23:40:54 $
+ *
  * src/sgfInchain.c, part of Complete Goban (game program)
  * Copyright (C) 1995 William Shubert.
  * See "configure.h.in" for more copyright information.
@@ -322,6 +327,7 @@ static const char  *readFile(Sgf *mc, FILE *f, int *crCount)  {
       break;
 
     case(TOKEN2('T','R')):
+    case(TOKEN1('M')):      /* Some games have marks as "M[..]". */
       arg_multi(arg, mc, sgfType_triangle, goStone_empty, &err);
       if (err)
 	return(msg_sgfBadLoc);
@@ -332,7 +338,11 @@ static const char  *readFile(Sgf *mc, FILE *f, int *crCount)  {
 	return(msg_sgfBadLoc);
       break;
     case(TOKEN2('M','A')):  /* I draw "MA" (mark) as a square.   */
-    case(TOKEN1('M')):      /* Some games have marks as "M[..]". */
+      arg_multi(arg, mc, sgfType_mark, goStone_empty, &err);
+      if (err)
+	return(msg_sgfBadLoc);
+      break;
+    case(TOKEN2('S','Q')):
       arg_multi(arg, mc, sgfType_square, goStone_empty, &err);
       if (err)
 	return(msg_sgfBadLoc);
