@@ -68,7 +68,7 @@ static ButOut  filePressed(But *but, int line);
 static void  fixPath(Str *pathOut, const char *pathIn);
 static void  addCwd(Str *pathOut);
 static bool  maskMatch(const char *mask, const char *fName, int fLen);
-static void  dirError(AbutFsel *f, int errno, const char *badDir);
+static void  dirError(AbutFsel *f, int errnov, const char *badDir);
 static ButOut  msgDead(void *packet);
 static ButOut  msgOkBut(But *but);
 
@@ -626,7 +626,7 @@ static bool  maskMatch(const char *mask, const char *fName, int fLen)  {
 }
 
 
-static void  dirError(AbutFsel *f, int errno, const char *badDir)  {
+static void  dirError(AbutFsel *f, int errnov, const char *badDir)  {
   Str  fullError;
   AbutMsgOpt  okBut;
 
@@ -639,7 +639,7 @@ static void  dirError(AbutFsel *f, int errno, const char *badDir)  {
   okBut.packet = f;
   okBut.keyEq = NULL;
   str_init(&fullError);
-  str_print(&fullError, abutFsel_dirErrMessage, strerror(errno), badDir);
+  str_print(&fullError, abutFsel_dirErrMessage, strerror(errnov), badDir);
   f->msg = abutMsg_optCreate(f->abut, f->win, 2, str_chars(&fullError),
 			     msgDead, f, 1, &okBut);
 }
