@@ -788,7 +788,11 @@ static ButOut  kpress(But *but, const char *newtext, KeySym keysym)  {
       need_draw = TRUE;
     } else if (tb->locs[tbin_loCur].index > 0)  {
       --tb->locs[tbin_loCur].index;
+      assert((drawHi < tb->loTinBreak) || (drawHi >= tb->hiTinBreak));
+      drawHi = tinNum_line(drawHi, tb);
       insertResult = insert(env, "", tb, but->w, &changePrev);
+      drawHi = tinNum_line2TinNum(drawHi, tb);
+      assert((drawHi < tb->loTinBreak) || (drawHi >= tb->hiTinBreak));
       need_draw = TRUE;
     } else if (tb->locs[tbin_loCur].tin > 0)  {
       if (tb->buf[tb->tins[tb->locs[tbin_loCur].tin].start - 1] == '\n')  {
@@ -800,8 +804,9 @@ static ButOut  kpress(But *but, const char *newtext, KeySym keysym)  {
       }
       insertResult = insert(env, "", tb, but->w, &changePrev);
       need_draw = TRUE;
-    } else
+    } else {
       result |= BUTOUT_ERR;
+    }
 #if 0  /* People don't like my delete.  :-( */
   } else if (keysym == XK_Delete)  {
     if ((tb->locs[tbin_loCur].index != tb->locs[tbin_hiCur].index) ||
@@ -910,19 +915,27 @@ static ButOut  kpress(But *but, const char *newtext, KeySym keysym)  {
     result |= BUTOUT_CAUGHT;
     if (tb->locs[tbin_loCur].tin < drawLo)
       drawLo = tb->locs[tbin_loCur].tin;
-    if (tb->locs[tbin_hiCur].tin > drawHi)
+    if (tb->locs[tbin_hiCur].tin > drawHi) {
       drawHi = tb->locs[tbin_hiCur].tin;
+      assert((drawHi < tb->loTinBreak) || (drawHi >= tb->hiTinBreak));
+    }
     if (changePrev && drawLo)  {
       drawLo = tinNum_prev(drawLo, tb);
     }
+    assert(drawHi >= drawLo);
     drawLo = tinNum_line(drawLo, tb) * butEnv_fontH(env, 0);
-    if (insertResult == insert_cr)
+    if (insertResult == insert_cr) {
       drawHi = but->h;
-    else
+    } else {
+      assert((drawHi < tb->loTinBreak) || (drawHi >= tb->hiTinBreak));
       drawHi = (tinNum_line(drawHi, tb) + 1) * butEnv_fontH(env, 0);
+    }
     if (drawLo < but->h)  {
-      if (drawHi > but->h)
+      assert(drawHi >= drawLo);
+      if (drawHi > but->h) {
 	drawHi = but->h;
+	assert(drawHi > drawLo);
+      }
       butWin_redraw(but->win, but->x,but->y+drawLo, but->w,drawHi - drawLo);
     }
   }
@@ -996,7 +1009,7 @@ static Insert  insert(ButEnv *env, const char *src, Tbin *tb, int butW,
     addMoreBufferSpace(tb);
   }
   assert(tb->tins[tb->locs[tbin_loCur].tin].start >= 0);
-  loTinWidthCheck = tb->locs[tbin_loCur].tin;
+  loTinWidthCheck = tinNum_line(tb->locs[tbin_loCur].tin, tb);
   for (i = 0;  i < len;  ++i)  {
     assert(tb->loTinBreak <= tb->hiTinBreak);
     assert(tb->tins[tb->locs[tbin_loCur].tin].start +
@@ -1066,9 +1079,9 @@ static Insert  insert(ButEnv *env, const char *src, Tbin *tb, int butW,
    * Now that the text is inserted, it is time to adjust the EOLs if we have
    *   to.
    */
-  tryJoinLines(tb, loTinWidthCheck, env, butW);
+  tryJoinLines(tb, tinNum_line2TinNum(loTinWidthCheck, tb), env, butW);
   lineBroken = TRUE;
-  for (i = loTinWidthCheck;
+  for (i = tinNum_line2TinNum(loTinWidthCheck, tb);
        (i < tb->maxTins) && ((i <= tb->locs[tbin_loCur].tin) || lineBroken);
        i = tinNum_next(i, tb))  {
     if (calcTinWidth(&tb->tins[i], tb->buf, env) > butW)  {
@@ -1189,6 +1202,8 @@ static void  breakLine(Tbin *tb, int tinNum, ButEnv *env, int butW)  {
   int  breakPoint, w;
   TbinLoc  loc;
 
+  assert(tinNum < tb->maxTins);
+  assert((tinNum < tb->loTinBreak) || (tinNum >= tb->hiTinBreak));
   if (butW <= 0)  {
     return;
   }
@@ -1666,6 +1681,17 @@ static void  checkOffWin(But *but, int mouseY, bool force)  {
 }
 
 
+/**
+ * Adjust the breakpoint of the text field.
+ *
+ * Parameters:
+ *   tb - The tbin being adjusted.
+ *   bType = Ony of:
+ *     break_loCur (move break to the lo cursor)
+ *     break_eoLoCur (move break to end of the line containing the lo cursor)
+ *     break_eol (move break to the end of line breakTin).
+ *   breakTin - Used in break_eol. Zero otherwise.
+ */
 static void  adjustBreak(Tbin *tb, BreakType bType, int breakTin)  {
   int  newLoBreak, breakIndex = 0, newHiBreak;
   int  origHiTinBreak, origLoTinBreak;
@@ -1688,6 +1714,8 @@ static void  adjustBreak(Tbin *tb, BreakType bType, int breakTin)  {
     breakIndex = tb->tins[tb->locs[tbin_loCur].tin].len;
     break;
   case break_eol:
+    assert(breakTin < tb->maxTins);
+    assert((breakTin < tb->loTinBreak) || (breakTin >= tb->hiTinBreak));
     breakIndex = tb->tins[breakTin].len;
     break;
   }
